@@ -84,7 +84,7 @@ impl Command for HelpCommand {
         );
         commands.insert(
             "start [root directory]",
-            String::from("Starts the mezzo app."),
+            String::from("Starts the mezzo project."),
         );
         commands.insert("help", String::from("Prints this message."));
 
