@@ -9,14 +9,13 @@ mod server;
 mod template;
 mod utils;
 
-use args::parse_args;
 use commands::{Command, HelpCommand, NewProjectCommand, StartProjectCommand};
 use std::env;
 
 fn main() {
     let raw_args: Vec<String> = env::args().collect();
 
-    let (command_type, args) = parse_args(&raw_args);
+    let (command_type, args) = args::parse_args(&raw_args);
 
     let command: Box<dyn Command> = match command_type.as_str() {
         "new" => Box::new(NewProjectCommand::new(args.get(0))),
