@@ -32,6 +32,22 @@ class ApiClient {
     const { data } = await response.json()
     return data
   }
+
+  async update<T>(
+    collection: string,
+    id: string,
+    entity: T
+  ): Promise<{ deleted: number }> {
+    const response = await fetch(`/api/${collection}/${id}`, {
+      method: 'PUT',
+      headers: {
+        'Content-Type': 'application/json',
+      },
+      body: JSON.stringify(entity),
+    })
+    const { data } = await response.json()
+    return data
+  }
 }
 
 export default new ApiClient()
